@@ -198,46 +198,6 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         cv2.waitKey(1)
         cv2.waitKey(1)
         
-    
-    def captureTestDimension(self):
-        cv2.destroyAllWindows()
-        cv2.waitKey(1)
-        cv2.waitKey(1)
-        
-        window_name = 'projector'
-        cv2.namedWindow(window_name)
-        cv2.moveWindow(window_name, self.displayWidth, 0)  #self.displayWidth
-            
-        
-        if not os.path.exists('CalibrationNumpyData/'):
-            os.mkdir('CalibrationNumpyData/')
-        if not os.path.exists('CalibrationImages/RadiometricTest/'):
-            os.mkdir('CalibrationImages/RadiometricTest/')
-       
-        pattern = np.zeros((DISPLAY_HEIGHT,DISPLAY_WIDTH))
-        cv2.imshow(window_name, pattern.astype(np.uint8))
-        cv2.waitKey(40)
-        self.camera.getImage(name = 'RadiometricTest/'+ 'testImage1', calibration=True)
-        
-        pattern = np.ones((DISPLAY_HEIGHT,DISPLAY_WIDTH)) * 255
-        cv2.imshow(window_name, pattern.astype(np.uint8))
-        cv2.waitKey(40)
-        self.camera.getImage(name = 'RadiometricTest/'+ 'testImage2', calibration=True)
-
-        image1 = cv2.imread("CalibrationImages/RadiometricTest/testImage1.PNG")
-        image2 = cv2.imread("CalibrationImages/RadiometricTest/testImage2.PNG")
-        image3 = image2 - image1
-        image3.clip(0,255)
-        
-        cv2.imwrite("CalibrationImages/RadiometricTest/testImage3.PNG",cv2.cvtColor(image3,cv2.COLOR_BGR2RGB))
-        
-        print('Capture Complete! Test images viewable at CalibrationImages/RadiometricTest/')
-        cv2.waitKey(1000)
-        cv2.destroyAllWindows()
-        cv2.waitKey(1)
-        cv2.waitKey(1)
-        
-        
     def captureTest(self):
         cv2.destroyAllWindows()
         cv2.waitKey(1)
@@ -261,28 +221,23 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         cv2.waitKey(40)
         self.camera.getImage(name = 'RadiometricTest/'+ 'testImage', calibration=True)
         
-        print('Capture Complete! Test image viewable at CalibrationImages/RadiometricTest/')
-        cv2.waitKey(1000)
-        cv2.destroyAllWindows()
-        cv2.waitKey(1)
-        cv2.waitKey(1)
+        pattern = np.zeros((DISPLAY_HEIGHT,DISPLAY_WIDTH))
+        cv2.imshow(window_name, pattern.astype(np.uint8))
+        cv2.waitKey(40)
+        self.camera.getImage(name = 'RadiometricTest/'+ 'testImage1', calibration=True)
         
-    
-    def vignettingcalibration(self):
-        cv2.destroyAllWindows()
-        cv2.waitKey(1)
-        cv2.waitKey(1)
+        pattern = np.ones((DISPLAY_HEIGHT,DISPLAY_WIDTH)) * 255
+        cv2.imshow(window_name, pattern.astype(np.uint8))
+        cv2.waitKey(40)
+        self.camera.getImage(name = 'RadiometricTest/'+ 'testImage2', calibration=True)
+
+        image1 = cv2.imread("CalibrationImages/RadiometricTest/testImage1.PNG")
+        image2 = cv2.imread("CalibrationImages/RadiometricTest/testImage2.PNG")
+        image3 = image2 - image1
+        image3.clip(0,255)
         
-        window_name = 'projector'
-        cv2.namedWindow(window_name)
-        cv2.moveWindow(window_name, self.displayWidth, 0)  #self.displayWidth
-            
+        cv2.imwrite("CalibrationImages/RadiometricTest/testImage3.PNG",cv2.cvtColor(image3,cv2.COLOR_BGR2RGB))
         
-        if not os.path.exists('CalibrationNumpyData/'):
-            os.mkdir('CalibrationNumpyData/')
-        if not os.path.exists('CalibrationImages/RadiometricTest/'):
-            os.mkdir('CalibrationImages/RadiometricTest/')
-       
         pattern = np.ones((DISPLAY_HEIGHT,DISPLAY_WIDTH)) * 128
         cv2.imshow(window_name, pattern.astype(np.uint8))
         cv2.waitKey(40)
@@ -292,7 +247,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         cv2.waitKey(1000)
         cv2.destroyAllWindows()
         cv2.waitKey(1)
-        cv2.waitKey(1)    
+        cv2.waitKey(1) 
         
         
         
